@@ -38,22 +38,8 @@ class FreqDict(models.Model):
         #Category loading
         #SyntacticCategory.objects.all().delete()
         self.loadCats()
-        lemmas = self.loadLemmas()
-        wfs = self.loadWF()
-        ls = []
-        for key in lemmas:
-            if int(lemmas[key]['CategoryNum']) > 12:
-                continue
-            cat = SyntacticCategory.objects.get(pk=int(lemmas[key]['CategoryNum']))
-            ls.append(Lemma(pk=int(key),FreqDict=self,Label=lemmas[key]['Word'],Category=cat,Frequency=int(lemmas[key]['Freq'])))
-        Lemma.objects.bulk_create(ls)
-        for key in wfs:
-            lem = Lemma.objects.get(pk=int(wfs[key]['IdLemma']))
-            wf = WordForm.objects.create(pk=int(key),Lemma = lem,Frequency = int(wfs[key]['Freq']))
-            ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[key]['Spellings'])
-            wf.Orthographies.add(*ss)
-            ts = (Transcription.objects.get_or_create(Transcription=t)[0] for t in wfs[key]['Transcriptions'])
-            wf.Transcriptions.add(*ts)
+        self.loadLemmas()
+        self.loadWF()
 
 
     def loadCats(self):
@@ -72,12 +58,22 @@ class FreqDict(models.Model):
         lemmas = self.loadOrthLemmas()
         #lemmas = self.loadTransLemmas(lemmas)
         lemmas = self.addCategories(lemmas)
-        return lemmas
+        ls = []
+        for key in lemmas:
+            cat = SyntacticCategory.objects.get_or_create(pk=int(lemmas[key]['CategoryNum']),defaults={'Label':'<UNK>'})[0]
+            ls.append(Lemma(pk=int(key),FreqDict=self,Label=lemmas[key]['Word'],Category=cat,Frequency=int(lemmas[key]['Freq'])))
+        Lemma.objects.bulk_create(ls)
 
     def loadWF(self):
         wfs = self.loadOrthWF()
         wfs = self.loadTransWF(wfs)
-        return wfs
+        for key in wfs:
+            lem = Lemma.objects.get(pk=int(wfs[key]['IdLemma']))
+            wf = WordForm.objects.create(pk=int(key),Lemma = lem,Frequency = int(wfs[key]['Freq']))
+            ss = (Orthography.objects.get_or_create(Spelling=s)[0] for s in wfs[key]['Spellings'])
+            wf.Orthographies.add(*ss)
+            ts = (Transcription.objects.get_or_create(Transcription=t)[0] for t in wfs[key]['Transcriptions'])
+            wf.Transcriptions.add(*ts)
 
     def loadOrthLemmas(self):
         lemmas = {}
@@ -158,7 +154,7 @@ class FreqDict(models.Model):
                     continue
                 main = l[:9]
                 additional = l[9:]
-                trans = [main[5]]
+                trans = [main[6]]
                 if len(additional) != 0:
                     additional = chunks(additional,4)
                     trans.extend([x[1] for x in additional])
